# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/laraauto/automobile/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/laraauto/automobile/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Laraauto\\Automobile\\": "packages/laraauto/automobile/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Laraauto\Automobile\Providers\AutomobileServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Automobile'  => Laraauto\Automobile\Facades\Automobile::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Laraauto\\AutomobileTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Laraauto\Automobile\Providers\AutomobileServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Laraauto\Automobile\Providers\AutomobileServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Laraauto\Automobile\Providers\AutomobileServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/automobile/{modulename}

**User**

    http://path-to-route-folder/user/automobile/{modulename}

**Public**

    http://path-to-route-folder/automobiles


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/automobile/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/automobile/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/automobile/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/automobile/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/automobile/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/automobile/{modulename}/{slug}
    METHOD: GET