<?php

namespace Laraauto\Automobile\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Laraauto\Automobile\Models\Automobile;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Laraauto\Automobile\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/automobile/automobile/*')) {
            Route::bind('automobile', function ($automobile) {
                $automobilerepo = $this->app->make('Laraauto\Automobile\Interfaces\AutomobileRepositoryInterface');
                return $automobilerepo->findorNew($automobile);
            });
        }

        if (Request::is('*/automobile/accessory/*')) {
            Route::bind('accessory', function ($accessory) {
                $accessoryrepo = $this->app->make('Laraauto\Automobile\Interfaces\AccessoryRepositoryInterface');
                return $accessoryrepo->findorNew($accessory);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
